@@ -102,6 +102,10 @@ class LocalizedContent(abc.ABC):
         """String representation of the content."""
         return self.__content
 
+    @content.setter
+    def content(self, value: str):
+        self.__content = value
+
     @property
     def language_code(self) -> LanguageCode:
         """Language code of the content."""
