@@ -1,7 +1,5 @@
 # -*- coding: utf-8 -*-
 # Copyright © 2021 Wacom. All rights reserved.
-
-# Vocabulary prefix
 from json import JSONEncoder
 from typing import List, Union, Set, Tuple
 
@@ -9,10 +7,14 @@ from knowledge import logger
 from knowledge.base.access import TenantAccessRight
 from knowledge.base.entity import *
 
-PREFIX: str = "xsd"
 
-# Vocabulary base URI
+# ---------------------------------------------- Vocabulary base URI ---------------------------------------------------
+PREFIX: str = "xsd"
 BASE_URI: str = "http://www.w3.org/2001/XMLSchema#"
+# ---------------------------------------------------- Constants -------------------------------------------------------
+SUB_CLASS_OF_TAG: str = 'subClassOf'
+TENANT_ID: str = 'tenantId'
+NAME_TAG: str = "name"
 
 
 class PropertyType(enum.Enum):
@@ -308,13 +310,13 @@ class OntologyClass(OntologyObject):
 
     @classmethod
     def from_dict(cls, concept_dict: Dict[str, Any]):
-        labels: List[Label] = [] if concept_dict['labels'] is None else \
-            [Label(content=la['text'], language_code=la['locale']) for la in concept_dict['labels']]
+        labels: List[Label] = [] if concept_dict[LABELS_TAG] is None else \
+            [Label(content=la[VALUE_TAG], language_code=la[LANGUAGE_CODE_TAG]) for la in concept_dict[LABELS_TAG]]
         comments: List[Comment] = [] if concept_dict['comments'] is None else \
-            [Comment(text=la['text'], language_code=la['locale']) for la in concept_dict['comments']]
-        return OntologyClass(tenant_id=concept_dict['tenantId'], context=concept_dict['context'],
-                             reference=OntologyClassReference.parse(concept_dict['name']),
-                             subclass_of=OntologyClassReference.parse(concept_dict['subClassOf']),
+            [Comment(text=la[VALUE_TAG], language_code=la[LANGUAGE_CODE_TAG]) for la in concept_dict['comments']]
+        return OntologyClass(tenant_id=concept_dict[TENANT_ID], context=concept_dict['context'],
+                             reference=OntologyClassReference.parse(concept_dict[NAME_TAG]),
+                             subclass_of=OntologyClassReference.parse(concept_dict[SUB_CLASS_OF_TAG]),
                              icon=concept_dict['icon'], labels=labels, comments=comments)
 
     @classmethod
@@ -410,7 +412,7 @@ class OntologyProperty(OntologyObject):
     @classmethod
     def from_dict(cls, property_dict: Dict[str, Any]):
         labels: List[Label] = [] if property_dict[LABELS_TAG] is None else \
-            [Label.create_from_dict(la, TEXT_TAG, LOCALE_TAG) for la in property_dict[LABELS_TAG]]
+            [Label.create_from_dict(la) for la in property_dict[LABELS_TAG]]
         comments: List[Comment] = [] if property_dict['comments'] is None else \
             [Comment.create_from_dict(co) for co in property_dict['comments']]
         return OntologyProperty(INVERSE_PROPERTY_TYPE[property_dict['kind']],
