@@ -899,299 +899,3 @@ class WacomKnowledgeService(WacomServiceAPIClient):
         for elem in response['result']:
             results.append(ThingObject.from_dict(elem))
         return results, response[NEXT_PAGE_ID_TAG]
-
-
-class TenantManagementServiceAPI(WacomServiceAPIClient):
-    """
-    Tenant Management Service API
-    -----------------------------
-
-    Functionality:
-        - List all tenants
-        - Create tenants
-        - Create users
-
-    Parameters
-    ----------
-    tenant_token: str
-        Tenant Management token
-    service_url: str
-        URL of the service
-    service_endpoint: str
-        Base endpoint
-    """
-
-    TENANT_ENDPOINT: str = 'tenant'
-    USER_DETAILS_ENDPOINT: str = f'{WacomServiceAPIClient.USER_ENDPOINT}/users'
-    SERVICE_URL: str = 'https://semantic-ink-private.wacom.com'
-
-    def __init__(self, tenant_token: str, service_url: str = SERVICE_URL, service_endpoint: str = 'graphdata'):
-        self.__tenant_management_token: str = tenant_token
-        super().__init__("TenantManagementServiceAPI", service_url=service_url, service_endpoint=service_endpoint)
-
-    @property
-    def tenant_management_token(self) -> str:
-        """Tenant Management token."""
-        return self.__tenant_management_token
-
-    @tenant_management_token.setter
-    def tenant_management_token(self, value: str):
-        self.__tenant_management_token = value
-
-    # ------------------------------------------ Tenants handling ------------------------------------------------------
-
-    def create_tenant(self, name: str) -> Dict[str, str]:
-        """
-        Creates a tenant.
-
-        Parameters
-        ----------
-        name: str -
-            Name of the tenant
-
-        Returns
-        -------
-        tenant_dict: Dict[str, str]
-
-        Newly created tenant structure.
-        >>>     {
-        >>>       "id": "<Tenant-ID>",
-        >>>       "apiKey": "<Tenant-API-Key>",
-        >>>       "name": "<Tenant-Name>"
-        >>>    }
-
-        Raises
-        ------
-        WacomServiceException
-            If the tenant service returns an error code.
-        """
-        url: str = '{}/{}{}'.format(self.service_url, self.service_endpoint,
-                                    TenantManagementServiceAPI.TENANT_ENDPOINT)
-        headers: dict = {
-            AUTHORIZATION_HEADER_FLAG: f'Bearer {self.__tenant_management_token}',
-            'Content-Type': 'application/json'
-        }
-        payload: dict = {
-            'name': name
-        }
-        response: Response = requests.post(url, headers=headers, json=payload, verify=self.verify_calls)
-        if response.ok:
-            return response.json()
-
-    def listing_tenant(self) -> List[Dict[str, str]]:
-        """
-        Listing all tenants configured for this instance.
-
-        Returns
-        -------
-        tenants:  List[Dict[str, str]]
-            List of tenants:
-            >>> [
-            >>>     {
-            >>>        "id": "<Tenant-ID>",
-            >>>        "apiKey": "<Tenant-API-Key>",
-            >>>        "name": "<Tenant-Name>"
-            >>>     },
-            >>>     ...
-            >>> ]
-        Raises
-        ------
-        WacomServiceException
-            If the tenant service returns an error code.
-        """
-        url: str = '{}/{}{}'.format(self.service_url, self.service_endpoint,
-                                    TenantManagementServiceAPI.TENANT_ENDPOINT)
-        headers: dict = {
-            AUTHORIZATION_HEADER_FLAG: f'Bearer {self.__tenant_management_token}'
-        }
-        response: Response = requests.get(url, headers=headers, data={}, verify=self.verify_calls)
-        if response.ok:
-            return response.json()
-        raise WacomServiceException(f'Response code:={response.status_code}, exception:= {response.text}')
-
-    # ------------------------------------------ Users handling --------------------------------------------------------
-
-    def create_user(self, tenant_key: str, external_id: str, meta_data: Dict[str, str] = None,
-                    roles: List[str] = None) -> Dict[str, Any]:
-        """
-        Creates user for a tenant.
-
-        Parameters
-        ----------
-        tenant_key: str -
-            API key for tenant
-        external_id: str -
-            External id of user identification service.
-        meta_data: Dict[str, str]
-            Meta-data dictionary.
-        roles: List[str]
-            List of roles.
-
-        Returns
-        -------
-        user: Dict[str, Any]
-            User info.
-
-        Raises
-        ------
-        WacomServiceException
-            If the tenant service returns an error code.
-        """
-        url: str = '{}/{}{}'.format(self.service_url, self.service_endpoint, TenantManagementServiceAPI.USER_ENDPOINT)
-        headers: dict = {
-            AUTHORIZATION_HEADER_FLAG: f'Bearer {self.__tenant_management_token}',
-            'x-tenant-api-key': tenant_key,
-            'Content-Type': 'application/json'
-        }
-        payload: dict = {
-            "externalUserId": external_id,
-            "metaData": meta_data if meta_data is not None else {},
-            "roles": roles if roles is not None else ['User']
-        }
-        response: Response = requests.post(url, headers=headers, json=payload, verify=self.verify_calls)
-        if response.ok:
-            return response.json()
-        raise WacomServiceException(f'Response code:={response.status_code}, exception:= {response.text}')
-
-    def update_user(self, tenant_key: str, internal_id: str, external_id: str, meta_data: Dict[str, str] = None,
-                    roles: List[str] = None) -> Dict[str, Any]:
-        """Updates user for a tenant.
-
-        Parameters
-        ----------
-        tenant_key: str
-            API key for tenant
-        internal_id: str
-            Internal id of semantic service.
-        external_id: str
-            External id of user identification service.
-        meta_data: Dict[str, str]
-            Meta-data dictionary.
-        roles: List[str]
-            List of roles.
-
-        Returns
-        -------
-        update: Dict[str, Any]
-            Updated information
-
-        Raises
-        ------
-        WacomServiceException
-            If the tenant service returns an error code.
-        """
-        url: str = '{}/{}{}'.format(self.service_url,
-                                    self.service_endpoint,
-                                    TenantManagementServiceAPI.USER_ENDPOINT)
-        headers: dict = {
-            AUTHORIZATION_HEADER_FLAG: f'Bearer {self.__tenant_management_token}',
-            'x-tenant-api-key': tenant_key,
-            'Content-Type': 'application/json'
-        }
-        payload: dict = {
-            "metaData": meta_data if meta_data is not None else {},
-            "roles": roles if roles is not None else []
-        }
-        params: dict = {
-            'userId': internal_id,
-            'externalUserId': external_id
-        }
-        response: Response = requests.patch(url, headers=headers, json=payload, params=params, verify=self.verify_calls)
-        if response.ok:
-            return response.json()
-        raise WacomServiceException(f'Response code:={response.status_code}, exception:= {response.text}')
-
-    def delete_user(self, tenant_key: str, external_id: str, internal_id: str):
-        """Deletes user from tenant.
-
-        Parameters
-        ----------
-        tenant_key: str
-            API key for tenant
-        external_id: str
-            External id of user identification service.
-        internal_id: str
-            Internal id of user.
-
-        Raises
-        ------
-        WacomServiceException
-            If the tenant service returns an error code.
-        """
-        url: str = '{}/{}{}'.format(self.service_url, self.service_endpoint, TenantManagementServiceAPI.USER_ENDPOINT)
-        headers: dict = {
-            AUTHORIZATION_HEADER_FLAG: f'Bearer {self.__tenant_management_token}',
-            'x-tenant-api-key': tenant_key
-        }
-        params: dict = {
-            'userId': internal_id,
-            'externalUserId': external_id
-        }
-        response: Response = requests.delete(url, headers=headers, params=params, verify=self.verify_calls)
-        if not response.ok:
-            raise WacomServiceException(f'Response code:={response.status_code}, exception:= {response.text}')
-
-    def user_internal_id(self, tenant_key: str, external_id: str) -> Dict[str, Any]:
-        """User internal id.
-
-        Parameters
-        ----------
-        tenant_key: str
-            API key for tenant
-        external_id: str
-            External id of user
-
-        Returns
-        -------
-        user_id: Dict[str, Any]
-            Internal id of users
-
-        Raises
-        ------
-        WacomServiceException
-            If the tenant service returns an error code.
-        """
-        url: str = f'{self.service_url}/{self.service_endpoint}{TenantManagementServiceAPI.USER_DETAILS_ENDPOINT}'
-        headers: dict = {
-            AUTHORIZATION_HEADER_FLAG: f'Bearer {self.__tenant_management_token}',
-            'x-tenant-api-key': tenant_key
-        }
-        parameters: Dict[str, str] = {
-            'externalUserId':  external_id
-        }
-        response: Response = requests.get(url, headers=headers, params=parameters, verify=self.verify_calls)
-        if response.ok:
-            return response.json()
-        raise WacomServiceException(f'Response code:={response.status_code}, exception:= {response.text}')
-
-    def listing_users(self, tenant_key: str, offset: int = 0, limit: int = 20) -> List[Dict[str, str]]:
-        """
-        Listing all users configured for this instance.
-
-        Parameters
-        ----------
-        tenant_key: str
-            API key for tenant
-        offset: int - [optional]
-            Offset value to define starting position in list. [DEFAULT:= 0]
-        limit: int - [optional]
-            Define the limit of the list size. [DEFAULT:= 20]
-
-        Returns
-        -------
-        user:  List[Dict[str, str]]
-            List of users.
-        """
-        url: str = f'{self.service_url}/{self.service_endpoint}{TenantManagementServiceAPI.USER_ENDPOINT}'
-        headers: dict = {
-            AUTHORIZATION_HEADER_FLAG: f'Bearer {self.__tenant_management_token}',
-            'x-tenant-api-key': tenant_key
-        }
-        params: dict = {
-            'offset': offset,
-            'limit': limit
-        }
-        response: Response = requests.get(url, headers=headers, params=params, verify=self.verify_calls)
-        if response.ok:
-            return response.json()
-        raise WacomServiceException(f'Response code:={response.status_code}, exception:= {response.text}')
